@@ -1,4 +1,4 @@
-from django.utils import simplejson
+import json
 from dajaxice.decorators import dajaxice_register
 
 
@@ -9,7 +9,7 @@ def test_registered_function(request):
 
 @dajaxice_register
 def test_string(request):
-    return simplejson.dumps({'string': 'hello world'})
+    return json.dumps({'string': 'hello world'})
 
 
 @dajaxice_register
@@ -19,25 +19,25 @@ def test_ajax_exception(request):
 
 @dajaxice_register
 def test_foo(request):
-    return simplejson.dumps({'foo': 'bar'})
+    return json.dumps({'foo': 'bar'})
 
 
 @dajaxice_register
 def test_foo_with_params(request, param1):
-    return simplejson.dumps({'param1': param1})
+    return json.dumps({'param1': param1})
 
 
 @dajaxice_register(method='GET')
 def test_get_register(request):
-    return simplejson.dumps({'foo': 'user'})
+    return json.dumps({'foo': 'user'})
 
 
 @dajaxice_register(method='GET', name="get_user_data")
 def test_get_with_name_register(request):
-    return simplejson.dumps({'bar': 'user'})
+    return json.dumps({'bar': 'user'})
 
 
 @dajaxice_register(method='GET', name="get_multi")
 @dajaxice_register(name="post_multi")
 def test_multi_register(request):
-    return simplejson.dumps({'foo': 'multi'})
+    return json.dumps({'foo': 'multi'})
