@@ -1,4 +1,4 @@
-import simplejson
+import json
 
 from dajaxice.decorators import dajaxice_register
 
@@ -6,21 +6,21 @@ from dajaxice.decorators import dajaxice_register
 @dajaxice_register(method='GET')
 @dajaxice_register(method='POST', name='other_post')
 def hello(request):
-    return simplejson.dumps({'message': 'hello'})
+    return json.dumps({'message': 'hello'})
 
 
 @dajaxice_register(method='GET')
 @dajaxice_register(method='POST', name="more.complex.bye")
 def bye(request):
     raise Exception("PUMMMM")
-    return simplejson.dumps({'message': 'bye'})
+    return json.dumps({'message': 'bye'})
 
 
 @dajaxice_register
 def lol(request):
-    return simplejson.dumps({'message': 'lol'})
+    return json.dumps({'message': 'lol'})
 
 
 @dajaxice_register(method='GET')
 def get_args(request, foo):
-    return simplejson.dumps({'message': 'hello get args %s' % foo})
+    return json.dumps({'message': 'hello get args %s' % foo})
